@@ -142,8 +142,8 @@ Patch_dealloc(Patch *self)
     Py_CLEAR(self->hunks);
     free(self->old_oid);
     free(self->new_oid);
-    // we do not have to free old_file_path and new_file_path, they will
-    // be freed by git_diff_list_free in Diff_dealloc
+    /* We do not have to free old_file_path and new_file_path, they will
+     * be freed by git_diff_list_free in Diff_dealloc */
     PyObject_Del(self);
 }
 
@@ -290,6 +290,8 @@ Diff_patch__get__(Diff *self)
     PyObject *py_patch = NULL;
 
     num = git_diff_num_deltas(self->list);
+    if (num == 0)
+        Py_RETURN_NONE;
     MALLOC(strings, num * sizeof(char*), cleanup);
 
     for (i = 0, len = 1; i < num ; ++i) {
