@@ -41,6 +41,6 @@
 PyObject* Diff_changes(Diff *self);
 PyObject* Diff_patch(Diff *self);
 
-PyObject* wrap_diff(git_diff_list *diff, Repository *repo);
+PyObject* wrap_diff(git_diff *diff, Repository *repo);
 
 #endif
